@@ -157,6 +157,8 @@ def get_jar_ram_actual(executable: str) -> tuple[str, str, int, int]:
 
 
 def shorten_string(string: str, max_length: int, right: bool = True) -> str:
+    if not string:
+        return string
     if len(string) > max_length:
         if right:
             return string[: max_length - 1] + "\N{HORIZONTAL ELLIPSIS}"
